@@ -19,7 +19,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 
@@ -34,10 +34,12 @@
 #include <sys/wait.h>
 #include <sys/types.h>
 #include <stdlib.h>
-#include <stdint.h>
 #include <pwd.h>
 #include <grp.h>
-#include <fcntl.h>
+
+#ifdef HAVE_USERSEC_H
+#include <usersec.h>
+#endif
 
 #include "Str.h"
 #include "Dir.h"
@@ -91,6 +93,12 @@ struct Process_T {
 };
 
 
+struct _usergroups {
+        int ngroups;
+        gid_t groups[NGROUPS_MAX];
+};
+
+
 /* --------------------------------------------------------------- Private */
 
 
@@ -213,6 +221,75 @@ static void _closeStreams(Process_T P) {
 }
 
 
+#ifndef HAVE_GETGROUPLIST
+#ifdef AIX
+static int getgrouplist(const char *name, int basegid, int *groups, int *ngroups) {
+        int rv = -1;
+
+        // Open the user database
+        if (setuserdb(S_READ) != 0) {
+                ERROR("Cannot open user database -- %s\n", System_getError(errno));
+                goto error4;
+        }
+
+        // Get administrative domain for the user so we can lookup the group membership in the correct database (files, LDAP, etc).
+        char *registry;
+        if (getuserattr((char *)name, S_REGISTRY, &registry, SEC_CHAR) == 0 && setauthdb(registry, NULL) != 0) {
+                ERROR("Administrative domain switch to %s for user %s failed -- %s\n", registry, name, System_getError(errno));
+                goto error3;
+        }
+
+        // Get the list of groups for the named user
+        char *groupList = getgrset(name);
+        if (! groupList) {
+                ERROR("Cannot get groups for user %s\n", name);
+                goto error2;
+        }
+
+        // Add the base GID
+        int count = 1;
+        groups[0] = basegid;
+
+        // Parse the comma separated list of groups
+        char *lastGroup = NULL;
+        for (char *currentGroup = strtok_r(groupList, ",", &lastGroup); currentGroup; currentGroup = strtok_r(NULL, ",", &lastGroup)) {
+                gid_t gid = (gid_t)Str_parseInt(currentGroup);
+                // Add the GID to the list (unless it's basegid, which we pushed to the beginning of groups list already)
+                if (gid != basegid) {
+                        if (count == *ngroups) {
+                                // Maximum groups reached (error will be indicated by -1 return value, but we return as many groups as possible in the list)
+                                goto error1;
+                        }
+                        groups[count++] = gid;
+                }
+        }
+
+        // Success
+        rv = 0;
+        *ngroups = count;
+
+error1:
+        FREE(groupList);
+
+error2:
+        // Restore the administrative domain
+        setauthdb(NULL, NULL);
+
+error3:
+        // Close the user database
+        if (enduserdb() != 0) {
+                ERROR("Cannot close user database -- %s\n", System_getError(errno));
+        }
+
+error4:
+        return rv;
+}
+#else
+#error "getgrouplist missing"
+#endif
+#endif
+
+
 /* -------------------------------------------------------------- Process_T */
 
 
@@ -282,9 +359,9 @@ int Process_waitFor(Process_T P) {
                 do
                         r = waitpid(P->pid, &P->status, 0); // Wait blocking
                 while (r == -1 && errno == EINTR);
-                if (r != P->pid) 
+                if (r != P->pid)
                         P->status = -1;
-                else 
+                else
                         _setstatus(P);
         }
         return P->status;
@@ -297,17 +374,17 @@ int Process_exitStatus(Process_T P) {
                 int r;
                 do
                         r = waitpid(P->pid, &P->status, WNOHANG); // Wait non-blocking
-                while (r == -1 && errno == EINTR); 
+                while (r == -1 && errno == EINTR);
                 if (r == 0) // Process is still running
                         P->status = -1;
-                else 
+                else
                         _setstatus(P);
         }
         return P->status;
 }
 
 
-int Process_isRunning(Process_T P) {
+bool Process_isRunning(Process_T P) {
         assert(P);
         return Process_exitStatus(P) < 0;
 }
@@ -473,7 +550,7 @@ const char *Command_getEnv(T C, const char *name) {
         if (e) {
                 char *v = strchr(e, '=');
                 if (v)
-                        return ++v;   
+                        return ++v;
         }
         return NULL;
 }
@@ -488,12 +565,31 @@ List_T Command_getCommand(T C) {
 /* The Execute function. Note that we use vfork() rather than fork. Vfork has
  a special semantic in that the child process runs in the parent address space
  until exec is called in the child. The child also run first and suspend the
- parent process until exec or exit is called */
+ parent process until exec or exit is called
+ 
+ Note: For possible better error reporting, set exec_error to an enum of possible
+ errors and exit with that error. Return Process_T regardless and introduce a
+ char *Process_getError() which uses waitpid() to get the error status from child exit.
+ I.e. similar to what we do with spawn.c
+ */
 Process_T Command_execute(T C) {
         assert(C);
         assert(_env(C));
         assert(_args(C));
         volatile int exec_error = 0;
+        struct _usergroups ug = (struct _usergroups){.groups = {}, .ngroups = NGROUPS_MAX};
+        if (C->uid) {
+                struct passwd *user = getpwuid(C->uid);
+                if (!user) {
+                        ERROR("Command: uid %d not found on the system -- %s\n", C->uid, System_getLastError());
+                        return NULL;
+                }
+                Command_setEnv(C, "HOME", user->pw_dir);
+                if (getgrouplist(user->pw_name, C->gid, (int *)ug.groups, &ug.ngroups) == -1) {
+                        ERROR("Command: getgrouplist for uid %d -- %s\n", C->uid, System_getLastError());
+                        return NULL;
+                }
+        }
         Process_T P = _Process_new();
         int descriptors = System_getDescriptorsGuarded();
         _createPipes(P);
@@ -501,12 +597,11 @@ Process_T Command_execute(T C) {
                 ERROR("Command: fork failed -- %s\n", System_getLastError());
                 Process_free(&P);
                 return NULL;
-        } else if (P->pid == 0) { 
+        } else if (P->pid == 0) {
                 // Child
                 if (C->working_directory) {
                         if (! Dir_chdir(C->working_directory)) {
                                 exec_error = errno;
-                                ERROR("Command: sub-process cannot change working directory to '%s' -- %s\n", C->working_directory, System_getLastError());
                                 _exit(errno);
                         }
                 }
@@ -521,26 +616,20 @@ Process_T Command_execute(T C) {
                         if (setgid(C->gid) == 0) {
                                 P->gid = C->gid;
                         } else {
-                                ERROR("Command: Cannot change process gid to '%d' -- %s\n", C->gid, System_getLastError());
+                                exec_error = errno;
+                                _exit(errno);
                         }
                 }
                 P->uid = getuid();
-                if (C->uid) {
-                        struct passwd *user = getpwuid(C->uid);
-                        if (user) {
-                                Command_setEnv(C, "HOME", user->pw_dir);
-                                if (initgroups(user->pw_name, P->gid) == 0) {
-                                        if (setuid(C->uid) == 0) {
-                                                P->uid = C->uid;
-                                        } else {
-                                                ERROR("Command: Cannot change process uid to '%d' -- %s\n", C->uid, System_getLastError());
-                                        }
-                                } else {
-                                        ERROR("Command: initgroups for user %s failed -- %s\n", user->pw_name, System_getLastError());
+                while (C->uid) {
+                        if (setgroups(ug.ngroups, ug.groups) == 0) {
+                                if (setuid(C->uid) == 0) {
+                                        P->uid = C->uid;
+                                        break;
                                 }
-                        } else {
-                                ERROR("Command: uid %d not found on the system -- %s\n", C->uid, System_getLastError());
                         }
+                        exec_error = errno;
+                        _exit(errno);
                 }
                 // Unblock any signals and reset signal handlers
                 sigset_t mask;
@@ -551,14 +640,11 @@ Process_T Command_execute(T C) {
                 signal(SIGABRT, SIG_DFL);
                 signal(SIGTERM, SIG_DFL);
                 signal(SIGPIPE, SIG_DFL);
-                signal(SIGCHLD, SIG_DFL); 
+                signal(SIGCHLD, SIG_DFL);
                 signal(SIGUSR1, SIG_DFL);
                 signal(SIGHUP, SIG_IGN);  // Ensure future opens won't allocate controlling TTYs
                 // Execute the program
                 execve(_args(C)[0], _args(C), _env(C));
-                // Won't print to error log as descriptor was closed above, but will
-                // print error to stderr Processor_T can be read
-                ERROR("Command: '%s' failed to execute -- %s", _args(C)[0], System_getLastError());
                 exec_error = errno;
                 _exit(errno);
         }
