@@ -40,7 +40,7 @@
 bool Filesystem_getByMountpoint(Info_T inf, const char *path) {
         ASSERT(inf);
         ASSERT(path);
-        LogError("Unsupported filesystem data collection method\n");
+        Log_error("Unsupported filesystem data collection method\n");
         return false;
 }
 
@@ -48,7 +48,7 @@ bool Filesystem_getByMountpoint(Info_T inf, const char *path) {
 bool Filesystem_getByDevice(Info_T inf, const char *path) {
         ASSERT(inf);
         ASSERT(path);
-        LogError("Unsupported filesystem data collection method\n");
+        Log_error("Unsupported filesystem data collection method\n");
         return false;
 }
 
