@@ -143,14 +143,14 @@ int initprocesstree_sysdep(ProcessTree_T **reference, ProcessEngine_Flags pflags
         char errbuf[_POSIX2_LINE_MAX];
         kvm_t *kvm_handle = kvm_openfiles(NULL, _PATH_DEVNULL, NULL, O_RDONLY, errbuf);
         if (! kvm_handle) {
-                LogError("system statistics error -- cannot initialize kvm interface\n");
+                Log_error("system statistics error -- cannot initialize kvm interface\n");
                 return 0;
         }
 
         int treesize;
         struct kinfo_proc *pinfo = kvm_getprocs(kvm_handle, KERN_PROC_PROC, 0, &treesize);
         if (! pinfo || (treesize < 1)) {
-                LogError("system statistics error -- kvm_getprocs: %s\n", kvm_geterr(kvm_handle));
+                Log_error("system statistics error -- kvm_getprocs: %s\n", kvm_geterr(kvm_handle));
                 kvm_close(kvm_handle);
                 return 0;
         }
@@ -225,27 +225,27 @@ bool used_system_memory_sysdep(SystemInfo_T *si) {
         size_t len = sizeof(unsigned int);
         unsigned int active;
         if (sysctlbyname("vm.stats.vm.v_active_count", &active, &len, NULL, 0) == -1) {
-                LogError("system statistics error -- cannot get active memory usage: %s\n", STRERROR);
+                Log_error("system statistics error -- cannot get active memory usage: %s\n", STRERROR);
                 return false;
         }
         if (len != sizeof(unsigned int)) {
-                LogError("system statistics error -- active memory usage statics error\n");
+                Log_error("system statistics error -- active memory usage statics error\n");
                 return false;
         }
         unsigned int wired;
         if (sysctlbyname("vm.stats.vm.v_wire_count", &wired, &len, NULL, 0) == -1) {
-                LogError("system statistics error -- cannot get wired memory usage: %s\n", STRERROR);
+                Log_error("system statistics error -- cannot get wired memory usage: %s\n", STRERROR);
                 return false;
         }
         if (len != sizeof(unsigned int)) {
-                LogError("system statistics error -- wired memory usage statics error\n");
+                Log_error("system statistics error -- wired memory usage statics error\n");
                 return false;
         }
         unsigned long long arcsize = 0ULL;
         len = sizeof(arcsize);
         if (sysctlbyname("kstat.zfs.misc.arcstats.size", &arcsize, &len, NULL, 0) == 0) {
                 if (len != sizeof(arcsize)) {
-                        LogError("system statistics error -- ZFS ARC memory usage statics error\n");
+                        Log_error("system statistics error -- ZFS ARC memory usage statics error\n");
                         return false;
                 }
         }
@@ -257,7 +257,7 @@ bool used_system_memory_sysdep(SystemInfo_T *si) {
         unsigned long long used  = 0ULL;
         size_t miblen = sizeof(mib) / sizeof(mib[0]);
         if (sysctlnametomib("vm.swap_info", mib, &miblen) == -1) {
-                LogError("system statistics error -- cannot get swap usage: %s\n", STRERROR);
+                Log_error("system statistics error -- cannot get swap usage: %s\n", STRERROR);
                 si->swap.size = 0ULL;
                 return false;
         }
@@ -269,7 +269,7 @@ bool used_system_memory_sysdep(SystemInfo_T *si) {
                 if (sysctl(mib, miblen + 1, &xsw, &len, NULL, 0) == -1)
                         break;
                 if (xsw.xsw_version != XSWDEV_VERSION) {
-                        LogError("system statistics error -- cannot get swap usage: xswdev version mismatch\n");
+                        Log_error("system statistics error -- cannot get swap usage: xswdev version mismatch\n");
                         si->swap.size = 0ULL;
                         return false;
                 }
@@ -296,13 +296,13 @@ bool used_system_cpu_sysdep(SystemInfo_T *si) {
 
         len = sizeof(mib);
         if (sysctlnametomib("kern.cp_time", mib, &len) == -1) {
-                LogError("system statistics error -- cannot get cpu time handler: %s\n", STRERROR);
+                Log_error("system statistics error -- cannot get cpu time handler: %s\n", STRERROR);
                 return false;
         }
 
         len = sizeof(cp_time);
         if (sysctl(mib, 2, &cp_time, &len, NULL, 0) == -1) {
-                LogError("system statistics error -- cannot get cpu time: %s\n", STRERROR);
+                Log_error("system statistics error -- cannot get cpu time: %s\n", STRERROR);
                 return false;
         }
 
