@@ -32,6 +32,7 @@
 
 // libmonit
 #include "exceptions/IOException.h"
+#include "exceptions/ProtocolException.h"
 
 /**
  *  Check the server for greeting code 220 and then send a QUIT and check for code 221
@@ -50,13 +51,13 @@ void check_ftp(Socket_T socket) {
                 Str_chomp(buf);
         } while (buf[3] == '-'); // Discard multi-line response
         if (sscanf(buf, "%d", &status) != 1 || status != 220)
-                THROW(IOException, "FTP greeting error: %s", buf);
+                THROW(ProtocolException, "FTP greeting error: %s", buf);
         if (Socket_print(socket, "QUIT\r\n") < 0)
                 THROW(IOException, "FTP: error sending data -- %s", STRERROR);
         if (! Socket_readLine(socket, buf, STRLEN))
                 THROW(IOException, "FTP: error receiving data -- %s", STRERROR);
         Str_chomp(buf);
         if (sscanf(buf, "%d", &status) != 1 || status != 221)
-                THROW(IOException, "FTP quit error: %s", buf);
+                THROW(ProtocolException, "FTP quit error: %s", buf);
 }
 
