@@ -32,6 +32,7 @@
 
 // libmonit
 #include "exceptions/IOException.h"
+#include "exceptions/ProtocolException.h"
 
 /**
  *  Check gpsd (http://www.catb.org/gpsd/) status.
@@ -56,6 +57,6 @@ void check_gps(Socket_T socket) {
         if (strncasecmp(buf, ok_gps_device, strlen(ok_gps_device)) != 0)
                 if (strncasecmp(buf, ok_rtcm104v2_device, strlen(ok_rtcm104v2_device)) != 0)
                         if (strncasecmp(buf, ok_rtcm104_device, strlen(ok_rtcm104_device)) != 0)
-                                THROW(IOException, "GPS error (no device): %s", buf);
+                                THROW(ProtocolException, "GPS error (no device): %s", buf);
 }
 
