@@ -66,16 +66,16 @@
 #define T Box_T
 struct T {
         struct {
-                unsigned row;
-                unsigned column;
+                unsigned int row;
+                unsigned int column;
         } index;
         struct {
                 struct {
-                        boolean_t enabled;
-                        char *color;
+                        bool enabled;
+                        const char *color;
                 } header;
         } options;
-        unsigned columnsCount;
+        unsigned int columnsCount;
         BoxColumn_T *columns;
         StringBuffer_T b;
 };
@@ -86,7 +86,7 @@ struct T {
 
 static void _printBorderTop(T t) {
         StringBuffer_append(t->b, COLOR_DARKGRAY BOX_DOWN_RIGHT BOX_HORIZONTAL);
-        for (int i = 0; i < t->columnsCount; i++) {
+        for (unsigned int i = 0; i < t->columnsCount; i++) {
                 for (int j = 0; j < t->columns[i].width; j++)
                         StringBuffer_append(t->b, BOX_HORIZONTAL);
                 if (i < t->columnsCount - 1)
@@ -98,7 +98,7 @@ static void _printBorderTop(T t) {
 
 static void _printBorderMiddle(T t) {
         StringBuffer_append(t->b, COLOR_DARKGRAY BOX_VERTICAL_RIGHT BOX_HORIZONTAL);
-        for (int i = 0; i < t->columnsCount; i++) {
+        for (unsigned int i = 0; i < t->columnsCount; i++) {
                 for (int j = 0; j < t->columns[i].width; j++)
                         StringBuffer_append(t->b, BOX_HORIZONTAL);
                 if (i < t->columnsCount - 1)
@@ -110,7 +110,7 @@ static void _printBorderMiddle(T t) {
 
 static void _printBorderBottom(T t) {
         StringBuffer_append(t->b, COLOR_DARKGRAY BOX_UP_RIGHT BOX_HORIZONTAL);
-        for (int i = 0; i < t->columnsCount; i++) {
+        for (unsigned int i = 0; i < t->columnsCount; i++) {
                 for (int j = 0; j < t->columns[i].width; j++)
                         StringBuffer_append(t->b, BOX_HORIZONTAL);
                 if (i < t->columnsCount - 1)
@@ -121,7 +121,7 @@ static void _printBorderBottom(T t) {
 
 
 static void _printHeader(T t) {
-        for (int i = 0; i < t->columnsCount; i++) {
+        for (unsigned int i = 0; i < t->columnsCount; i++) {
                 StringBuffer_append(t->b, COLOR_DARKGRAY BOX_VERTICAL COLOR_RESET " ");
                 StringBuffer_append(t->b, "%s%-*s%s", t->options.header.color, t->columns[i].width, t->columns[i].name, COLOR_RESET);
                 StringBuffer_append(t->b, " ");
@@ -132,7 +132,7 @@ static void _printHeader(T t) {
 
 
 static void _cacheColor(BoxColumn_T *column) {
-        boolean_t ansi = false;
+        bool ansi = false;
         if (column->value) {
                 for (int i = 0, k = 0; column->value[i]; i++) {
                         if (column->value[i] == '\033' && column->value[i + 1] == '[') {
@@ -153,16 +153,16 @@ static void _cacheColor(BoxColumn_T *column) {
 
 
 // Print a row. If wrap is enabled and the text excceeds width, return true (printed text up to column width, repetition possible to print the rest), otherwise false
-static boolean_t _printRow(T t) {
-        boolean_t repeat = false;
-        for (int i = 0; i < t->columnsCount; i++) {
+static bool _printRow(T t) {
+        bool repeat = false;
+        for (unsigned int i = 0; i < t->columnsCount; i++) {
                 StringBuffer_append(t->b, COLOR_DARKGRAY BOX_VERTICAL COLOR_RESET " ");
                 if (*(t->columns[i]._color))
                         StringBuffer_append(t->b, "%s", t->columns[i]._color);
                 if (! t->columns[i].value || t->columns[i]._cursor > strlen(t->columns[i].value) - 1) {
-                        // Empty column pading
+                        // Empty column padding
                         StringBuffer_append(t->b, "%*s", t->columns[i].width, " ");
-                } else if (strlen(t->columns[i].value + t->columns[i]._cursor) > t->columns[i].width) {
+                } else if (strlen(t->columns[i].value + t->columns[i]._cursor) > (unsigned long)t->columns[i].width) {
                         if (t->columns[i].wrap) {
                                 // The value exceeds the column width and should be wrapped
                                 int column = 0;
@@ -199,7 +199,7 @@ static void _resetColumn(BoxColumn_T *column) {
 
 
 static void _resetRow(T t) {
-        for (int i = 0; i < t->columnsCount; i++)
+        for (unsigned int i = 0; i < t->columnsCount; i++)
                 _resetColumn(&(t->columns[i]));
 }
 
@@ -207,7 +207,7 @@ static void _resetRow(T t) {
 /* -------------------------------------------------------- Public Methods */
 
 
-T Box_new(StringBuffer_T b, int columnsCount, BoxColumn_T *columns, boolean_t printHeader) {
+T Box_new(StringBuffer_T b, int columnsCount, BoxColumn_T *columns, bool printHeader) {
         ASSERT(b);
         ASSERT(columns);
         ASSERT(columnsCount > 0);
@@ -228,13 +228,13 @@ void Box_free(T *t) {
         ASSERT(t && *t);
         if ((*t)->index.row > 0)
                 _printBorderBottom(*t);
-        for (int i = 0; i < (*t)->columnsCount; i++)
+        for (unsigned int i = 0; i < (*t)->columnsCount; i++)
                 FREE((*t)->columns[i].value);
         FREE(*t);
 }
 
 
-void Box_setColumn(T t, int index, const char *format, ...) {
+void Box_setColumn(T t, unsigned int index, const char *format, ...) {
         ASSERT(t);
         ASSERT(index > 0);
         ASSERT(index <= t->columnsCount);
@@ -265,7 +265,7 @@ void Box_printRow(T t) {
         } else {
                 _printBorderMiddle(t);
         }
-        boolean_t repeat = false;
+        bool repeat = false;
         do {
                 repeat = _printRow(t);
         } while (repeat);
@@ -277,7 +277,7 @@ char *Box_strip(char *s) {
         if (STR_DEF(s)) {
                 int x, y;
                 unsigned char *_s = (unsigned char *)s;
-                boolean_t separator = false;
+                bool separator = false;
                 for (x = 0, y = 0; s[y]; y++) {
                         if (! separator) {
                                 if (_s[y] == 0xE2 && _s[y + 1] == 0x94) {
